npstructures.raggedshape.RaggedShape
====================================

.. currentmodule:: npstructures.raggedshape

.. autoclass:: RaggedShape

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~RaggedShape.__init__
      ~RaggedShape.asshape
      ~RaggedShape.broadcast_values
      ~RaggedShape.empty_rows_removed
      ~RaggedShape.from_dict
      ~RaggedShape.index_array
      ~RaggedShape.ravel_multi_index
      ~RaggedShape.to_dict
      ~RaggedShape.unravel_multi_index
      ~RaggedShape.view
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~RaggedShape.ends
      ~RaggedShape.lengths
      ~RaggedShape.n_rows
      ~RaggedShape.size
      ~RaggedShape.starts
   
   